@@ -21,9 +21,9 @@
 """Provides getCharacterName that maps punctuation marks and other
 individual characters into localized words."""
 
-__id__        = "$Id: chnames.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: chnames.py 4411 2009-01-08 15:09:09Z wwalker $"
+__version__   = "$Revision: 4411 $"
+__date__      = "$Date: 2009-01-08 15:09:09 +0000 (Thu, 08 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -576,6 +576,10 @@ chnames[u'\u2018'] = _("left single quote")
 #
 chnames[u'\u2019'] = _("right single quote")
 
+# Translators: this is the spoken word for the character '‚' (U+201a)
+#
+chnames[u'\u201a'] = _("single low quote")
+
 # Translators: this is the spoken word for the character '“' (U+201c)
 #
 chnames[u'\u201c'] = _("left double quote")
@@ -584,6 +588,10 @@ chnames[u'\u201c'] = _("left double quote")
 #
 chnames[u'\u201d'] = _("right double quote")
 
+# Translators: this is the spoken word for the character '„' (U+201e)
+#
+chnames[u'\u201e'] = _("double low quote")
+
 # Translators: this is the spoken word for the character '†' (U+2020)
 #
 chnames[u'\u2020'] = _("dagger")
