@@ -24,9 +24,9 @@ machine to speak.  Each speech server provides a set of known
 voices (identified by name) which can be combined with various
 attributes to create aural style sheets."""
 
-__id__        = "$Id: speechserver.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: speechserver.py 4467 2009-01-27 16:40:00Z wwalker $"
+__version__   = "$Revision: 4467 $"
+__date__      = "$Date: 2009-01-27 11:40:00 -0500 (Tue, 27 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -34,6 +34,8 @@ import logging
 import keynames
 import settings
 import orca
+import orca_state
+
 log = logging.getLogger("speech")
 
 import debug
@@ -200,6 +202,9 @@ class SpeechServer(object):
         # this key event.
         #
         event_string = keynames.getKeyName(event_string)
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            event_string = \
+                orca_state.activeScript.adjustForPronunciation(event_string)
 
         if eventType == orca.KeyEventType.LOCKING_LOCKED:
             # Translators: this represents the state of a locking modifier
